@@ -10,33 +10,43 @@ an :class:`.HTML` object, an :class:`.ANSI` object or a sequence of
 `(style_string, text)` tuples. The :func:`.to_formatted_text` conversion
 function takes any of these and turns all of them into such a tuple sequence.
 """
-from __future__ import unicode_literals
-from .base import to_formatted_text, is_formatted_text, Template, merge_formatted_text, FormattedText
-from .html import HTML
 from .ansi import ANSI
+from .base import (
+    AnyFormattedText,
+    FormattedText,
+    StyleAndTextTuples,
+    Template,
+    is_formatted_text,
+    merge_formatted_text,
+    to_formatted_text,
+)
+from .html import HTML
 from .pygments import PygmentsTokens
-from .utils import fragment_list_len, fragment_list_width, fragment_list_to_text, split_lines
+from .utils import (
+    fragment_list_len,
+    fragment_list_to_text,
+    fragment_list_width,
+    split_lines,
+)
 
 __all__ = [
     # Base.
-    'to_formatted_text',
-    'is_formatted_text',
-    'Template',
-    'merge_formatted_text',
-    'FormattedText',
-
+    "AnyFormattedText",
+    "to_formatted_text",
+    "is_formatted_text",
+    "Template",
+    "merge_formatted_text",
+    "FormattedText",
+    "StyleAndTextTuples",
     # HTML.
-    'HTML',
-
+    "HTML",
     # ANSI.
-    'ANSI',
-
+    "ANSI",
     # Pygments.
-    'PygmentsTokens',
-
+    "PygmentsTokens",
     # Utils.
-    'fragment_list_len',
-    'fragment_list_width',
-    'fragment_list_to_text',
-    'split_lines',
+    "fragment_list_len",
+    "fragment_list_width",
+    "fragment_list_to_text",
+    "split_lines",
 ]
