@@ -1,5 +1,5 @@
 from .base import DummyInput, Input
-from .defaults import create_input
+from .defaults import create_input, create_pipe_input
 
 __all__ = [
     # Base.
@@ -7,4 +7,5 @@ __all__ = [
     "DummyInput",
     # Defaults.
     "create_input",
+    "create_pipe_input",
 ]
